osmith has posted comments on this change by osmith. ( https://gerrit.osmocom.org/c/osmo-ci/+/41960?usp=email )
Change subject: jobs: disable ttcn3-gbproxy-test-fr
......................................................................
Set Ready For Review
--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/41960?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I15fcb4fd1f145bd913456ac08356e9fa65e34269
Gerrit-Change-Number: 41960
Gerrit-PatchSet: 2
Gerrit-Owner: osmith <osmith(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Comment-Date: Wed, 28 Jan 2026 11:28:42 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: No
Attention is currently required from: fixeria, laforge.
Hello Jenkins Builder,
I'd like you to reexamine a change. Please visit
https://gerrit.osmocom.org/c/pysim/+/41890?usp=email
to look at the new patch set (#3).
The following approvals got outdated and were removed:
Verified+1 by Jenkins Builder
Change subject: pySimLogger: user __name__ of the module when creating a new logger
......................................................................
pySimLogger: user __name__ of the module when creating a new logger
At the moment we use random identifiers as names when we create a
new logger for pySimLogger. Let's switch to consistently use the
module name here. For the top level modules let's use the program
name so that it will show up in the log instead of __init__.
Change-Id: I49a9beb98845f66247edd42ed548980c97a7151a
---
M contrib/csv-to-pgsql.py
M contrib/es2p_server.py
M pySim-shell.py
M pySim/card_key_provider.py
M pySim/log.py
M pySim/runtime.py
M tests/unittests/test_log.py
7 files changed, 13 insertions(+), 13 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/pysim refs/changes/90/41890/3
--
To view, visit https://gerrit.osmocom.org/c/pysim/+/41890?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: pysim
Gerrit-Branch: master
Gerrit-Change-Id: I49a9beb98845f66247edd42ed548980c97a7151a
Gerrit-Change-Number: 41890
Gerrit-PatchSet: 3
Gerrit-Owner: dexter <pmaier(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-CC: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-CC: laforge <laforge(a)osmocom.org>
Gerrit-Attention: laforge <laforge(a)osmocom.org>
Gerrit-Attention: fixeria <vyanitskiy(a)sysmocom.de>
Attention is currently required from: fixeria, laforge.
dexter has posted comments on this change by dexter. ( https://gerrit.osmocom.org/c/pysim/+/41890?usp=email )
Change subject: pySimLogger: user __name__ of the module when creating a new logger
......................................................................
Patch Set 3:
(4 comments)
File contrib/csv-to-pgsql.py:
https://gerrit.osmocom.org/c/pysim/+/41890/comment/3454230a_e2a27094?usp=em… :
PS1, Line 38: log = PySimLogger.get(__name__)
> Indeed, `log` should be accessible globally. […]
I have re-tested this. There seems to be no problem when removing the line. I think I was just irritated. Maybe the problems I had when I was writing the original code were caused by something else that resolved itself later.
File contrib/csv-to-pgsql.py:
https://gerrit.osmocom.org/c/pysim/+/41890/comment/ac897176_428d8634?usp=em… :
PS2, Line 15: log = PySimLogger.get("csv-to-pqsql")
> you can generalize this with […]
Thanks for the hint. This works fine. I have updated it now in the other code locations as well.
File contrib/es2p_server.py:
https://gerrit.osmocom.org/c/pysim/+/41890/comment/6da24d19_7e307dbe?usp=em… :
PS2, Line 35: logger = logging.getLogger("es2p_server")
> you can generalize this with […]
Done
File pySim/card_key_provider.py:
https://gerrit.osmocom.org/c/pysim/+/41890/comment/67cfccd3_240db4ec?usp=em… :
PS1, Line 41: PySimLogger.get
> I was wrong about inheriting configuration of the parent loggers then. […]
ACK, then we work on this later. I think it would be great if we could make it work this way. Things would be a lot simpler then.
--
To view, visit https://gerrit.osmocom.org/c/pysim/+/41890?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: pysim
Gerrit-Branch: master
Gerrit-Change-Id: I49a9beb98845f66247edd42ed548980c97a7151a
Gerrit-Change-Number: 41890
Gerrit-PatchSet: 3
Gerrit-Owner: dexter <pmaier(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-CC: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-CC: laforge <laforge(a)osmocom.org>
Gerrit-Attention: laforge <laforge(a)osmocom.org>
Gerrit-Attention: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Comment-Date: Wed, 28 Jan 2026 11:20:19 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: laforge <laforge(a)osmocom.org>
Comment-In-Reply-To: fixeria <vyanitskiy(a)sysmocom.de>
Comment-In-Reply-To: dexter <pmaier(a)sysmocom.de>
Attention is currently required from: dexter.
Hello Jenkins Builder, fixeria, laforge,
I'd like you to reexamine a change. Please visit
https://gerrit.osmocom.org/c/pysim/+/41812?usp=email
to look at the new patch set (#4).
The following approvals got outdated and were removed:
Verified+1 by Jenkins Builder
The change is no longer submittable: Verified is unsatisfied now.
Change subject: transport/init: use PySimLogger to print messages
......................................................................
transport/init: use PySimLogger to print messages
The module still uses print to output information. Let's replace
those print calls with the more modern PySimLogger method calls.
Change-Id: I2e2ec2b84f3b84dbd8a029ae9bb64b7a96ddbde3
---
M pySim/transport/__init__.py
1 file changed, 11 insertions(+), 8 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/pysim refs/changes/12/41812/4
--
To view, visit https://gerrit.osmocom.org/c/pysim/+/41812?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: pysim
Gerrit-Branch: master
Gerrit-Change-Id: I2e2ec2b84f3b84dbd8a029ae9bb64b7a96ddbde3
Gerrit-Change-Number: 41812
Gerrit-PatchSet: 4
Gerrit-Owner: dexter <pmaier(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Attention: dexter <pmaier(a)sysmocom.de>
laforge has submitted this change. ( https://gerrit.osmocom.org/c/libosmocore/+/41950?usp=email )
Change subject: osmo_io: Fix misalignment of iofd->cmsg used as struct cmsghdr
......................................................................
osmo_io: Fix misalignment of iofd->cmsg used as struct cmsghdr
Fixes following ASAN runtime error:
"""
src/stream.c:398:47: runtime error: member access within misaligned address 0x516000012b81 for type 'struct cmsghdr', which requires 8 byte alignment
0x516000012b81: note: pointer points here
51 00 00 00 30 00 00 00 00 00 00 00 84 00 00 00 01 00 00 00 00 00 00 00 00 00 00 00 00 00 00 03
^
"""
Current GCC documentation [1] states that __attribute__ ((__aligned__
(alignment))) is the older sytnax. The newer _Alignas mimics the
standarized alignas() in C23. Since we build with CLAGS=-std=gnu11 we
are fine using _Alignas, which was introduced in C11.
[1] https://www.gnu.org/software/c-intro-and-ref/manual/html_node/Type-Alignmen…
Related: OS#6905
Change-Id: Ia80dfc4dbffe85514b18dcf8d36b85bfafd76d64
---
M src/core/osmo_io_internal.h
1 file changed, 5 insertions(+), 2 deletions(-)
Approvals:
Jenkins Builder: Verified
osmith: Looks good to me, but someone else must approve
jolly: Looks good to me, but someone else must approve
laforge: Looks good to me, approved
--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/41950?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: merged
Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: Ia80dfc4dbffe85514b18dcf8d36b85bfafd76d64
Gerrit-Change-Number: 41950
Gerrit-PatchSet: 3
Gerrit-Owner: pespin <pespin(a)sysmocom.de>
Gerrit-Reviewer: Hoernchen <ewild(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel <dwillmann(a)sysmocom.de>
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: jolly <andreas(a)eversberg.eu>
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Attention is currently required from: Hoernchen, daniel, fixeria, pespin.
laforge has posted comments on this change by pespin. ( https://gerrit.osmocom.org/c/libosmocore/+/41950?usp=email )
Change subject: osmo_io: Fix misalignment of iofd->cmsg used as struct cmsghdr
......................................................................
Patch Set 3:
(1 comment)
Patchset:
PS1:
> CSMG_ALIGN returns the whole size including the required alignment, which is not what we want here. […]
Done
--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/41950?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: Ia80dfc4dbffe85514b18dcf8d36b85bfafd76d64
Gerrit-Change-Number: 41950
Gerrit-PatchSet: 3
Gerrit-Owner: pespin <pespin(a)sysmocom.de>
Gerrit-Reviewer: Hoernchen <ewild(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel <dwillmann(a)sysmocom.de>
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: jolly <andreas(a)eversberg.eu>
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Gerrit-Attention: Hoernchen <ewild(a)sysmocom.de>
Gerrit-Attention: pespin <pespin(a)sysmocom.de>
Gerrit-Attention: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Attention: daniel <dwillmann(a)sysmocom.de>
Gerrit-Comment-Date: Wed, 28 Jan 2026 11:14:43 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: laforge <laforge(a)osmocom.org>
Comment-In-Reply-To: pespin <pespin(a)sysmocom.de>
osmith has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-ci/+/41960?usp=email )
Change subject: ttcn3-gbproxy-test-fr: don't use old libosmocore
......................................................................
ttcn3-gbproxy-test-fr: don't use old libosmocore
Fix that we are currently building osmo-gbproxy against an old
libosmocore in ttcn3-gbproxy-test-fr. This is currently causing the job
to fail with:
/usr/bin/ld: gb_proxy_vty.o: in function `log_set_bvc_filter':
/tmp/osmo-gbproxy/src/gb_proxy_vty.c:477: undefined reference to `log_set_filter'
/usr/bin/ld: /tmp/osmo-gbproxy/src/gb_proxy_vty.c:478: undefined reference to `log_set_filter_data'
collect2: error: ld returned 1 exit status
Related: libosmocore Ie48e7e635feb91509b9c034394df4fb16cb931a3
Change-Id: I15fcb4fd1f145bd913456ac08356e9fa65e34269
---
M jobs/ttcn3-testsuites.yml
1 file changed, 20 insertions(+), 0 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/osmo-ci refs/changes/60/41960/1
diff --git a/jobs/ttcn3-testsuites.yml b/jobs/ttcn3-testsuites.yml
index 3202212..b7e0e51 100644
--- a/jobs/ttcn3-testsuites.yml
+++ b/jobs/ttcn3-testsuites.yml
@@ -145,6 +145,26 @@
cd "$DIR"
+ # For ttcn3-gbproxy-test-fr, build debian-buster-build first, so we
+ # don't build osmo-gbproxy against an old libosmocore:
+ # * ttcn3-gbproxy-test-fr must run with debian 10 (OS#6494#note-19).
+ # * osmo-gbproxy-master uses debian-buster-build.
+ # * osmo-gbproxy-master installs libosmocore (and other dependencies)
+ # from the osmocom:nightly binary repository, but builds
+ # osmo-gbproxy from git.
+ # * The Dockerfile of debian-buster-build invalidates the cache at
+ # the end if the osmocom:nightly binary repository has changed.
+ # * osmo-gbproxy-master relies on this, if the cache is not
+ # invalidated then it will install libosmocore etc. once and keep
+ # using the same versions via a cached build step.
+ # * We don't build debian-buster-build automatically anymore (because
+ # Debian 10 is EOL and this container is unused otherwise; this is
+ # done for e.g. debian-trixie-build as of writing via the
+ # "update-osmo-ci-on-slaves" job).
+ if [ "$IMAGE_SUFFIX" = "master-debian10" ]; then
+ make -C debian-buster-build
+ fi
+
uptime | grep --color=always -o "load.*"
RC=0
diff --git a/src/core/osmo_io_internal.h b/src/core/osmo_io_internal.h
index c15262b..4f35fee 100644
--- a/src/core/osmo_io_internal.h
+++ b/src/core/osmo_io_internal.h
@@ -170,8 +170,11 @@
/*! msghdr is in the cancel_queue list */
bool in_cancel_queue;
- /*! control message buffer for passing sctp_sndrcvinfo along */
- char cmsg[0]; /* size is determined by iofd->cmsg_size on recvmsg, and by mcghdr->msg_controllen on sendmsg */
+ /*! control message buffer for passing sctp_sndrcvinfo along.
+ * Size is determined by iofd->cmsg_size on recvmsg, and by mcghdr->msg_controllen on sendmsg.
+ * Alignment of the array is required due to cast to "struct cmsghdr", eg. by CMSG_FIRSTHDR().
+ */
+ char _Alignas(struct cmsghdr) cmsg[0];
};
enum iofd_seg_act {
--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/41960?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I15fcb4fd1f145bd913456ac08356e9fa65e34269
Gerrit-Change-Number: 41960
Gerrit-PatchSet: 1
Gerrit-Owner: osmith <osmith(a)sysmocom.de>
Attention is currently required from: Timur Davydov.
laforge has posted comments on this change by Timur Davydov. ( https://gerrit.osmocom.org/c/libosmocore/+/41941?usp=email )
Change subject: core: guard Linux netlink headers by libmnl usage
......................................................................
Patch Set 3: Code-Review+2
--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/41941?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I0b681deb1f1e025e3ea9996f19b1de06a5feb408
Gerrit-Change-Number: 41941
Gerrit-PatchSet: 3
Gerrit-Owner: Timur Davydov <dtv.comp(a)gmail.com>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Gerrit-Attention: Timur Davydov <dtv.comp(a)gmail.com>
Gerrit-Comment-Date: Wed, 28 Jan 2026 10:07:46 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Attention is currently required from: fixeria, pespin.
laforge has posted comments on this change by pespin. ( https://gerrit.osmocom.org/c/libosmocore/+/41891?usp=email )
Change subject: logging: Make struct log_context and struct log_target private
......................................................................
Patch Set 10:
(1 comment)
Patchset:
PS1:
> @laforge@gnumonks.org Yes, I think I already listed them in a comment here. […]
"Existing users" to me means "all the preeviously released versions of the applications which must continue to work with libosmocore after this patch has been merged.
"existing users" is not code that has just been hot-patched a few days ago to avoid the issue introduced here.
--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/41891?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: Iecbd07995ccb465a44be0debcc97458b2b240a0e
Gerrit-Change-Number: 41891
Gerrit-PatchSet: 10
Gerrit-Owner: pespin <pespin(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-CC: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-CC: osmith <osmith(a)sysmocom.de>
Gerrit-Attention: pespin <pespin(a)sysmocom.de>
Gerrit-Attention: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Comment-Date: Wed, 28 Jan 2026 10:06:34 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: laforge <laforge(a)osmocom.org>
Comment-In-Reply-To: pespin <pespin(a)sysmocom.de>
Comment-In-Reply-To: fixeria <vyanitskiy(a)sysmocom.de>